@@ -36,6 +36,7 @@ use DateTimeZone;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
 use PHPUnit\Framework\Attributes\DoesNotPerformAssertions;
+use PHPUnit\Framework\Attributes\IgnorePhpunitDeprecations;
 use PHPUnit\Framework\Attributes\Small;
 use PHPUnit\TestFixture\Author;
 use PHPUnit\TestFixture\Book;
@@ -142,6 +143,130 @@ final class AssertTest extends TestCase
         $this->assertContainsOnlyInstancesOf(Book::class, $test2);
     }
 
+    public function testAssertArrayIsEqualToArrayOnlyConsideringListOfKeys(): void
+    {
+        $expected = ['a' => 'b', 'b' => 'c', 0 => 1, 1 => 2];
+        $actual   = ['a' => 'b', 'b' => 'b', 0 => 1, 1 => 3];
+
+        $this->assertArrayIsEqualToArrayOnlyConsideringListOfKeys($expected, $actual, ['a', 0]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsEqualToArrayOnlyConsideringListOfKeys($expected, $actual, ['b']);
+    }
+
+    public function testAssertArrayIsEqualToArrayIgnoringListOfKeys(): void
+    {
+        $expected = ['a' => 'b', 'b' => 'c', 0 => 1, 1 => 2];
+        $actual   = ['a' => 'b', 'b' => 'b', 0 => 1, 1 => 3];
+
+        $this->assertArrayIsEqualToArrayIgnoringListOfKeys($expected, $actual, ['b', 1]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsEqualToArrayIgnoringListOfKeys($expected, $actual, ['b']);
+    }
+
+    public function testAssertArrayIsIdenticalToArrayOnlyConsideringListOfKeys(): void
+    {
+        $expected = ['a' => 'b', 'b' => 'c', 0 => 1, 1 => 2];
+        $actual   = ['a' => 'b', 'b' => 'b', 0 => 1, 1 => 3];
+
+        $this->assertArrayIsIdenticalToArrayOnlyConsideringListOfKeys($expected, $actual, ['a', 0]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsIdenticalToArrayOnlyConsideringListOfKeys($expected, $actual, ['b']);
+    }
+
+    public function testAssertArrayIsIdenticalToArrayIgnoringListOfKeys(): void
+    {
+        $expected = ['a' => 'b', 'b' => 'c', 0 => 1, 1 => 2];
+        $actual   = ['a' => 'b', 'b' => 'b', 0 => 1, 1 => 3];
+
+        $this->assertArrayIsIdenticalToArrayIgnoringListOfKeys($expected, $actual, ['b', 1]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsIdenticalToArrayIgnoringListOfKeys($expected, $actual, ['b']);
+    }
+
+    public function testAssertArrayIsEqualToArrayOnlyConsideringListOfKeysInterpretsKeysSameAsPHP(): void
+    {
+        // Effective keys: int 0, int 1, int 2, string '3.0'.
+        $expected = [0 => 1, '1' => 2, 2.0 => 3, '3.0' => 4];
+        $actual   = [0 => 1, '1' => 2, 2.0 => 2, '3.0' => 4];
+
+        $this->assertArrayIsEqualToArrayOnlyConsideringListOfKeys($expected, $actual, [0, '1', '3.0']);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsEqualToArrayOnlyConsideringListOfKeys($expected, $actual, ['1', 2.0, '3.0']);
+    }
+
+    public function testAssertArrayIsEqualToArrayIgnoringListOfKeysInterpretsKeysSameAsPHP(): void
+    {
+        // Effective keys: int 0, int 1, int 2, string '3.0'.
+        $expected = [0 => 1, '1' => 2, 2.0 => 3, '3.0' => 4];
+        $actual   = [0 => 1, '1' => 2, 2.0 => 2, '3.0' => 4];
+
+        $this->assertArrayIsEqualToArrayIgnoringListOfKeys($expected, $actual, [2.0]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsEqualToArrayIgnoringListOfKeys($expected, $actual, ['1']);
+    }
+
+    public function testAssertArrayIsIdenticalToArrayOnlyConsideringListOfKeysInterpretsKeysSameAsPHP(): void
+    {
+        // Effective keys: int 0, int 1, int 2, string '3.0'.
+        $expected = [0 => 1, '1' => 2, 2.0 => 3, '3.0' => 4];
+        $actual   = [0 => 1, '1' => 2, 2.0 => 2, '3.0' => 4];
+
+        $this->assertArrayIsIdenticalToArrayOnlyConsideringListOfKeys($expected, $actual, [0, '1', '3.0']);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsIdenticalToArrayOnlyConsideringListOfKeys($expected, $actual, ['1', 2.0, '3.0']);
+    }
+
+    public function testAssertArrayIsIdenticalToArrayIgnoringListOfKeysInterpretsKeysSameAsPHP(): void
+    {
+        // Effective keys: int 0, int 1, int 2, string '3.0'.
+        $expected = [0 => 1, '1' => 2, 2.0 => 3, '3.0' => 4];
+        $actual   = [0 => 1, '1' => 2, 2.0 => 2, '3.0' => 4];
+
+        $this->assertArrayIsIdenticalToArrayIgnoringListOfKeys($expected, $actual, [2.0]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsIdenticalToArrayIgnoringListOfKeys($expected, $actual, ['1']);
+    }
+
+    public function testAssertArrayIsEqualButNotIdenticalToArrayOnlyConsideringListOfKeys(): void
+    {
+        $expected = ['a' => 'b', 'b' => 'c', 0 => 1, 1 => 2];
+        $actual   = [0 => 1, 1 => 3, 'a' => 'b', 'b' => 'b'];
+
+        $this->assertArrayIsEqualToArrayOnlyConsideringListOfKeys($expected, $actual, ['a', 0]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsIdenticalToArrayOnlyConsideringListOfKeys($expected, $actual, ['a', 0]);
+    }
+
+    public function testAssertArrayIsEqualButNotIdenticalToArrayIgnoringListOfKeys(): void
+    {
+        $expected = ['a' => 'b', 'b' => 'c', 0 => 1, 1 => 2];
+        $actual   = [0 => 1, 1 => 3, 'a' => 'b', 'b' => 'b'];
+
+        $this->assertArrayIsEqualToArrayIgnoringListOfKeys($expected, $actual, ['b', 1]);
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertArrayIsIdenticalToArrayIgnoringListOfKeys($expected, $actual, ['b', 1]);
+    }
+
     public function testAssertArrayHasIntegerKey(): void
     {
         $this->assertArrayHasKey(0, ['foo']);
@@ -1224,6 +1349,7 @@ XML;
         $this->assertStringMatchesFormat('*%s*', '**');
     }
 
+    #[IgnorePhpunitDeprecations]
     public function testAssertStringNotMatchesFormat(): void
     {
         $this->assertStringNotMatchesFormat('*%s*', '**');
@@ -1528,11 +1654,28 @@ XML;
         $this->assertNotInstanceOf(stdClass::class, new stdClass);
     }
 
-    public function testAssertStringMatchesFormatFileThrowsExceptionForInvalidArgument(): void
+    public function testAssertFileMatchesFormat(): void
     {
-        $this->expectException(Exception::class);
+        $this->assertFileMatchesFormat("FOO\n", TEST_FILES_PATH . 'expectedFileFormat.txt');
 
-        $this->assertStringMatchesFormatFile('not_existing_file', '');
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertFileMatchesFormat("BAR\n", TEST_FILES_PATH . 'expectedFileFormat.txt');
+    }
+
+    public function testAssertFileMatchesFormatFile(): void
+    {
+        $this->assertFileMatchesFormatFile(
+            TEST_FILES_PATH . 'expectedFileFormat.txt',
+            TEST_FILES_PATH . 'expectedFileFormat.txt',
+        );
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertFileMatchesFormatFile(
+            TEST_FILES_PATH . 'expectedFileFormat.txt',
+            TEST_FILES_PATH . 'actualFileFormat.txt',
+        );
     }
 
     public function testAssertStringMatchesFormatFile(): void
@@ -1544,13 +1687,7 @@ XML;
         $this->assertStringMatchesFormatFile(TEST_FILES_PATH . 'expectedFileFormat.txt', "BAR\n");
     }
 
-    public function testAssertStringNotMatchesFormatFileThrowsExceptionForInvalidArgument(): void
-    {
-        $this->expectException(Exception::class);
-
-        $this->assertStringNotMatchesFormatFile('not_existing_file', '');
-    }
-
+    #[IgnorePhpunitDeprecations]
     public function testAssertStringNotMatchesFormatFile(): void
     {
         $this->assertStringNotMatchesFormatFile(TEST_FILES_PATH . 'expectedFileFormat.txt', "BAR\n");
@@ -1560,6 +1697,29 @@ XML;
         $this->assertStringNotMatchesFormatFile(TEST_FILES_PATH . 'expectedFileFormat.txt', "FOO\n");
     }
 
+    public function testAssertFileEqualsCanonicalizing(): void
+    {
+        $this->assertFileNotEquals(TEST_FILES_PATH . 'foo.txt', TEST_FILES_PATH . 'bar.txt');
+        $this->assertFileEqualsCanonicalizing(TEST_FILES_PATH . 'foo.txt', TEST_FILES_PATH . 'foo.txt');
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertFileEqualsCanonicalizing(TEST_FILES_PATH . 'foo.txt', TEST_FILES_PATH . 'foo.xml');
+    }
+
+    public function testAssertStringNotEqualsFileCanonicalizing(): void
+    {
+        $contents = file_get_contents(TEST_FILES_PATH . 'foo.xml');
+
+        $this->assertStringNotEqualsFileCanonicalizing(TEST_FILES_PATH . 'foo.xml', $contents . ' BAR');
+
+        $this->assertStringNotEqualsFileCanonicalizing(TEST_FILES_PATH . 'foo.xml', 'BAR');
+
+        $this->expectException(AssertionFailedError::class);
+
+        $this->assertStringNotEqualsFileCanonicalizing(TEST_FILES_PATH . 'foo.xml', $contents);
+    }
+
     public function testStringsCanBeComparedForEqualityIgnoringCase(): void
     {
         $this->assertEqualsIgnoringCase('a', 'A');
@@ -2122,6 +2282,19 @@ XML;
         $this->fail();
     }
 
+    public function testTwoObjectsCanBeAssertedToNotBeEqualUsingComparisonMethod(): void
+    {
+        $this->assertObjectNotEquals(new ValueObject(1), new ValueObject(2));
+
+        try {
+            $this->assertObjectNotEquals(new ValueObject(1), new ValueObject(1));
+        } catch (AssertionFailedError) {
+            return;
+        }
+
+        $this->fail();
+    }
+
     public function testObjectHasPropertyCanBeAsserted(): void
     {
         $objectWithProperty              = new stdClass;
