@@ -10,10 +10,17 @@
 namespace PHPUnit\Framework\MockObject;
 
 use Exception;
+use PHPUnit\Framework\Attributes\IgnorePhpunitDeprecations;
+use PHPUnit\Framework\Attributes\RequiresPhp;
 use PHPUnit\Framework\Attributes\TestDox;
+use PHPUnit\Framework\Attributes\Ticket;
 use PHPUnit\Framework\TestCase;
+use PHPUnit\TestFixture\MockObject\ExtendableClassCallingMethodInDestructor;
 use PHPUnit\TestFixture\MockObject\ExtendableClassWithCloneMethod;
+use PHPUnit\TestFixture\MockObject\ExtendableReadonlyClassWithCloneMethod;
 use PHPUnit\TestFixture\MockObject\InterfaceWithMethodThatExpectsObject;
+use PHPUnit\TestFixture\MockObject\InterfaceWithMethodThatHasDefaultParameterValues;
+use PHPUnit\TestFixture\MockObject\InterfaceWithNeverReturningMethod;
 use PHPUnit\TestFixture\MockObject\InterfaceWithReturnTypeDeclaration;
 use stdClass;
 
@@ -34,6 +41,7 @@ abstract class TestDoubleTestCase extends TestCase
     }
 
     #[TestDox('__toString() method returns empty string when return value generation is disabled and no return value is configured')]
+    #[IgnorePhpunitDeprecations]
     final public function testToStringMethodReturnsEmptyStringWhenReturnValueGenerationIsDisabledAndNoReturnValueIsConfigured(): void
     {
         $double = $this->getMockBuilder(InterfaceWithReturnTypeDeclaration::class)
@@ -43,6 +51,7 @@ abstract class TestDoubleTestCase extends TestCase
         $this->assertSame('', $double->__toString());
     }
 
+    #[IgnorePhpunitDeprecations]
     final public function testMethodDoesNotReturnValueWhenReturnValueGenerationIsDisabledAndNoReturnValueIsConfigured(): void
     {
         $double = $this->getMockBuilder(InterfaceWithReturnTypeDeclaration::class)
@@ -84,6 +93,7 @@ abstract class TestDoubleTestCase extends TestCase
         $this->assertSame($object, $double->doSomething($object));
     }
 
+    #[IgnorePhpunitDeprecations]
     public function testCloningOfObjectsPassedAsArgumentCanBeEnabled(): void
     {
         $object = new stdClass;
@@ -136,6 +146,26 @@ abstract class TestDoubleTestCase extends TestCase
         $this->assertSame(4, $double->doSomethingElse(3));
     }
 
+    final public function testMethodWithDefaultParameterValuesCanBeConfiguredToReturnValuesBasedOnArgumentMapping(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithMethodThatHasDefaultParameterValues::class);
+
+        $double->method('doSomething')->willReturnMap([[1, 2, 3], [4, 5, 6]]);
+
+        $this->assertSame(3, $double->doSomething(1, 2));
+        $this->assertSame(6, $double->doSomething(4, 5));
+    }
+
+    final public function testMethodWithDefaultParameterValuesCanBeConfiguredToReturnValuesBasedOnArgumentMappingThatOmitsDefaultValues(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithMethodThatHasDefaultParameterValues::class);
+
+        $double->method('doSomething')->willReturnMap([[1, 2], [3, 4]]);
+
+        $this->assertSame(2, $double->doSomething(1));
+        $this->assertSame(4, $double->doSomething(3));
+    }
+
     final public function testMethodCanBeConfiguredToReturnValuesUsingCallback(): void
     {
         $double = $this->createTestDouble(InterfaceWithReturnTypeDeclaration::class);
@@ -166,6 +196,21 @@ abstract class TestDoubleTestCase extends TestCase
         $this->assertTrue($double->doSomething());
     }
 
+    final public function testMethodConfiguredToReturnDifferentValuesOnConsecutiveCallsCannotBeCalledMoreOftenThanReturnValuesHaveBeenConfigured(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithReturnTypeDeclaration::class);
+
+        $double->method('doSomething')->willReturn(false, true);
+
+        $this->assertFalse($double->doSomething());
+        $this->assertTrue($double->doSomething());
+
+        $this->expectException(NoMoreReturnValuesConfiguredException::class);
+        $this->expectExceptionMessage('Only 2 return values have been configured for PHPUnit\TestFixture\MockObject\InterfaceWithReturnTypeDeclaration::doSomething()');
+
+        $double->doSomething();
+    }
+
     final public function testMethodCanBeConfiguredToReturnDifferentValuesAndThrowExceptionsOnConsecutiveCalls(): void
     {
         $double = $this->createTestDouble(InterfaceWithReturnTypeDeclaration::class);
@@ -203,16 +248,26 @@ abstract class TestDoubleTestCase extends TestCase
         $this->fail();
     }
 
+    final public function testMethodWithNeverReturnTypeDeclarationThrowsException(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithNeverReturningMethod::class);
+
+        $this->expectException(NeverReturningMethodException::class);
+        $this->expectExceptionMessage('Method PHPUnit\TestFixture\MockObject\InterfaceWithNeverReturningMethod::m() is declared to never return');
+
+        $double->m();
+    }
+
     #[TestDox('Original __clone() method is not called by default when test double object is cloned')]
-    public function testOriginalCloneMethodIsNotCalledByDefaultWhenTestDoubleObjectIsCloned(): void
+    final public function testOriginalCloneMethodIsNotCalledByDefaultWhenTestDoubleObjectIsCloned(): void
     {
         $double = clone $this->createTestDouble(ExtendableClassWithCloneMethod::class);
 
-        $this->assertFalse($double->method());
+        $this->assertFalse($double->doSomething());
     }
 
     #[TestDox('Original __clone() method can optionally be called when test double object is cloned')]
-    public function testOriginalCloneMethodCanOptionallyBeCalledWhenTestDoubleObjectIsCloned(): void
+    final public function testOriginalCloneMethodCanOptionallyBeCalledWhenTestDoubleObjectIsCloned(): void
     {
         $double = $this->getMockBuilder(ExtendableClassWithCloneMethod::class)->enableOriginalClone()->getMock();
 
@@ -222,17 +277,58 @@ abstract class TestDoubleTestCase extends TestCase
         clone $double;
     }
 
-    /**
-     * @psalm-template RealInstanceType of object
-     *
-     * @psalm-param class-string<RealInstanceType> $type
-     *
-     * @psalm-return (Stub|MockObject)&RealInstanceType
-     */
-    abstract protected function createTestDouble(string $type): object;
+    #[TestDox('Original __clone() method is not called by default when test double object is cloned (readonly class)')]
+    #[RequiresPhp('8.3')]
+    final public function testOriginalCloneMethodIsNotCalledByDefaultWhenTestDoubleObjectOfReadonlyClassIsCloned(): void
+    {
+        $double = clone $this->createTestDouble(ExtendableReadonlyClassWithCloneMethod::class);
+
+        $this->assertFalse($double->doSomething());
+    }
+
+    #[TestDox('Original __clone() method can optionally be called when test double object is cloned (readonly class)')]
+    #[RequiresPhp('8.3')]
+    final public function testOriginalCloneMethodCanOptionallyBeCalledWhenTestDoubleObjectOfReadonlyClassIsCloned(): void
+    {
+        $double = $this->getMockBuilder(ExtendableReadonlyClassWithCloneMethod::class)->enableOriginalClone()->getMock();
+
+        $this->expectException(Exception::class);
+        $this->expectExceptionMessage(ExtendableReadonlyClassWithCloneMethod::class . '::__clone');
+
+        clone $double;
+    }
+
+    public function testMethodNameCanOnlyBeConfiguredOnce(): void
+    {
+        $double = $this->createTestDouble(InterfaceWithReturnTypeDeclaration::class);
+
+        $this->expectException(MethodNameAlreadyConfiguredException::class);
+
+        $double
+            ->method('doSomething')
+            ->method('doSomething')
+            ->willReturn(true);
+    }
+
+    #[Ticket('https://github.com/sebastianbergmann/phpunit/issues/5874')]
+    public function testDoubledMethodsCanBeCalledFromDestructorOnTestDoubleCreatedByTheReturnValueGenerator(): void
+    {
+        $this->markTestIncomplete('https://github.com/sebastianbergmann/phpunit/issues/5874');
+
+        $double = $this->createTestDouble(ExtendableClassCallingMethodInDestructor::class);
+
+        $this->assertInstanceOf(
+            ExtendableClassCallingMethodInDestructor::class,
+            $double->doSomething(),
+        );
+    }
 
     /**
-     * @psalm-param list<class-string> $interfaces
+     * @template RealInstanceType of object
+     *
+     * @param class-string<RealInstanceType> $type
+     *
+     * @return (MockObject|Stub)&RealInstanceType
      */
-    abstract protected function createTestDoubleForIntersection(array $interfaces): object;
+    abstract protected function createTestDouble(string $type): object;
 }
