@@ -13,10 +13,11 @@ use function array_merge;
 use function range;
 use PHPUnit\Framework\Attributes\CoversClass;
 use PHPUnit\Framework\Attributes\DataProvider;
+use PHPUnit\Framework\Attributes\Group;
 use PHPUnit\Framework\Attributes\Small;
+use PHPUnit\Framework\Attributes\TestDox;
 use PHPUnit\Framework\CodeCoverageException;
 use PHPUnit\Framework\TestCase;
-use PHPUnit\Framework\TestSuite;
 use PHPUnit\TestFixture\CoverageClassNothingTest;
 use PHPUnit\TestFixture\CoverageClassTest;
 use PHPUnit\TestFixture\CoverageClassWithoutAnnotationsTest;
@@ -24,6 +25,7 @@ use PHPUnit\TestFixture\CoverageCoversOverridesCoversNothingTest;
 use PHPUnit\TestFixture\CoverageFunctionParenthesesTest;
 use PHPUnit\TestFixture\CoverageFunctionParenthesesWhitespaceTest;
 use PHPUnit\TestFixture\CoverageFunctionTest;
+use PHPUnit\TestFixture\CoverageMethodAnnotationTest;
 use PHPUnit\TestFixture\CoverageMethodNothingCoversMethod;
 use PHPUnit\TestFixture\CoverageMethodNothingTest;
 use PHPUnit\TestFixture\CoverageMethodOneLineAnnotationTest;
@@ -32,7 +34,9 @@ use PHPUnit\TestFixture\CoverageMethodParenthesesWhitespaceTest;
 use PHPUnit\TestFixture\CoverageMethodTest;
 use PHPUnit\TestFixture\CoverageNamespacedFunctionTest;
 use PHPUnit\TestFixture\CoverageNoneTest;
-use PHPUnit\TestFixture\IgnoringCodeUnitsTest;
+use PHPUnit\TestFixture\CoverageTraitMethodTest;
+use PHPUnit\TestFixture\CoverageTraitTest;
+use PHPUnit\TestFixture\InterfaceAsTargetWithAttributeTest;
 use PHPUnit\TestFixture\InterfaceTargetTest;
 use PHPUnit\TestFixture\InvalidClassTargetWithAnnotationTest;
 use PHPUnit\TestFixture\InvalidClassTargetWithAttributeTest;
@@ -47,6 +51,7 @@ use PHPUnit\TestFixture\Test3194;
 
 #[CoversClass(CodeCoverage::class)]
 #[Small]
+#[Group('metadata')]
 final class CodeCoverageTest extends TestCase
 {
     public static function linesToBeCoveredProvider(): array
@@ -60,7 +65,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(29, 46),
+                    TEST_FILES_PATH . 'CoveredClass.php' => array_merge(range(12, 27), range(29, 46)),
                 ],
                 CoverageClassTest::class,
                 'testSomething',
@@ -74,6 +79,14 @@ final class CodeCoverageTest extends TestCase
                 'testSomething',
             ],
 
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                ],
+                CoverageMethodAnnotationTest::class,
+                'testSomething',
+            ],
+
             [
                 [
                     TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
@@ -190,11 +203,27 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . '3194.php' => array_merge(range(14, 20), range(22, 30)),
+                    TEST_FILES_PATH . '3194.php' => array_merge(range(15, 21), range(23, 31)),
                 ],
                 Test3194::class,
                 'testOne',
             ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredTrait.php' => range(12, 18),
+                ],
+                CoverageTraitTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredTrait.php' => range(14, 17),
+                ],
+                CoverageTraitMethodTest::class,
+                'testSomething',
+            ],
         ];
     }
 
@@ -209,7 +238,7 @@ final class CodeCoverageTest extends TestCase
 
             [
                 [
-                    TEST_FILES_PATH . 'CoveredClass.php' => range(29, 46),
+                    TEST_FILES_PATH . 'CoveredClass.php' => array_merge(range(12, 27), range(29, 46)),
                 ],
                 CoverageClassTest::class,
                 'testSomething',
@@ -223,6 +252,14 @@ final class CodeCoverageTest extends TestCase
                 'testSomething',
             ],
 
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredClass.php' => range(31, 35),
+                ],
+                CoverageMethodAnnotationTest::class,
+                'testSomething',
+            ],
+
             [
                 [
                     TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
@@ -302,6 +339,22 @@ final class CodeCoverageTest extends TestCase
                 CoverageNamespacedFunctionTest::class,
                 'testFunc',
             ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredTrait.php' => range(12, 18),
+                ],
+                CoverageTraitTest::class,
+                'testSomething',
+            ],
+
+            [
+                [
+                    TEST_FILES_PATH . 'CoveredTrait.php' => range(14, 17),
+                ],
+                CoverageTraitMethodTest::class,
+                'testSomething',
+            ],
         ];
     }
 
@@ -317,7 +370,7 @@ final class CodeCoverageTest extends TestCase
     }
 
     /**
-     * @psalm-param class-string $className
+     * @param class-string $className
      */
     #[DataProvider('linesToBeCoveredProvider')]
     public function testLinesToBeCoveredCanBeDetermined(array|false $expected, string $className, string $methodName): void
@@ -332,7 +385,7 @@ final class CodeCoverageTest extends TestCase
     }
 
     /**
-     * @psalm-param class-string $className
+     * @param class-string $className
      */
     #[DataProvider('linesToBeUsedProvider')]
     public function testLinesToBeUsedCanBeDetermined(array|false $expected, string $className, string $methodName): void
@@ -347,7 +400,7 @@ final class CodeCoverageTest extends TestCase
     }
 
     /**
-     * @psalm-param class-string $testCase
+     * @param class-string $testCase
      */
     #[DataProvider('canSkipCoverageProvider')]
     public function testWhetherCollectionOfCodeCoverageDataCanBeSkippedCanBeDetermined(string $testCase, bool $expectedCanSkip): void
@@ -359,7 +412,7 @@ final class CodeCoverageTest extends TestCase
         $this->assertEquals($expectedCanSkip, $canSkipCoverage);
     }
 
-    #[\PHPUnit\Framework\Attributes\TestDox('Rejects more than one @coversDefaultClass annotation')]
+    #[TestDox('Rejects more than one @coversDefaultClass annotation')]
     public function testRejectsMoreThanOneCoversDefaultClassAnnotation(): void
     {
         $this->expectException(CodeCoverageException::class);
@@ -368,7 +421,7 @@ final class CodeCoverageTest extends TestCase
         (new CodeCoverage)->linesToBeCovered(MoreThanOneCoversDefaultClassAnnotationTest::class, 'testOne');
     }
 
-    #[\PHPUnit\Framework\Attributes\TestDox('More than one @usesDefaultClass annotation')]
+    #[TestDox('More than one @usesDefaultClass annotation')]
     public function testRejectsMoreThanOneUsesDefaultClassAnnotation(): void
     {
         $this->expectException(CodeCoverageException::class);
@@ -385,10 +438,26 @@ final class CodeCoverageTest extends TestCase
         (new CodeCoverage)->linesToBeCovered(InterfaceTargetTest::class, 'testOne');
     }
 
+    public function testRejectsInterfaceAsCoversClassTargetWithAttribute(): void
+    {
+        $this->expectException(CodeCoverageException::class);
+        $this->expectExceptionMessage('Interface "Throwable" is not a valid target for code coverage');
+
+        (new CodeCoverage)->linesToBeCovered(InterfaceAsTargetWithAttributeTest::class, 'testOne');
+    }
+
+    public function testRejectsInterfaceAsUsesClassTargetWithAttribute(): void
+    {
+        $this->expectException(CodeCoverageException::class);
+        $this->expectExceptionMessage('Interface "Throwable" is not a valid target for code coverage');
+
+        (new CodeCoverage)->linesToBeUsed(InterfaceAsTargetWithAttributeTest::class, 'testOne');
+    }
+
     public function testRejectsInvalidCoversClassTargetWithAttribute(): void
     {
         $this->expectException(CodeCoverageException::class);
-        $this->expectExceptionMessage('Class "InvalidClass" is not a valid target for code coverage');
+        $this->expectExceptionMessage('"InvalidClass" is not a valid target for code coverage');
 
         (new CodeCoverage)->linesToBeCovered(InvalidClassTargetWithAttributeTest::class, 'testOne');
     }
@@ -396,7 +465,7 @@ final class CodeCoverageTest extends TestCase
     public function testRejectsInvalidUsesClassTargetWithAttribute(): void
     {
         $this->expectException(CodeCoverageException::class);
-        $this->expectExceptionMessage('Class "InvalidClass" is not a valid target for code coverage');
+        $this->expectExceptionMessage('"InvalidClass" is not a valid target for code coverage');
 
         (new CodeCoverage)->linesToBeUsed(InvalidClassTargetWithAttributeTest::class, 'testOne');
     }
@@ -420,7 +489,7 @@ final class CodeCoverageTest extends TestCase
     public function testRejectsInvalidCoversFunctionTarget(): void
     {
         $this->expectException(CodeCoverageException::class);
-        $this->expectExceptionMessage('Function "::invalid_function" is not a valid target for code coverage');
+        $this->expectExceptionMessage('::invalid_function is not a valid target for code coverage');
 
         (new CodeCoverage)->linesToBeCovered(InvalidFunctionTargetTest::class, 'testOne');
     }
@@ -428,19 +497,8 @@ final class CodeCoverageTest extends TestCase
     public function testRejectsInvalidUsesFunctionTarget(): void
     {
         $this->expectException(CodeCoverageException::class);
-        $this->expectExceptionMessage('Function "::invalid_function" is not a valid target for code coverage');
+        $this->expectExceptionMessage('::invalid_function is not a valid target for code coverage');
 
         (new CodeCoverage)->linesToBeUsed(InvalidFunctionTargetTest::class, 'testOne');
     }
-
-    public function testCanIgnoreCodeUnits(): void
-    {
-        $this->assertSame(
-            [
-                TEST_FILES_PATH . 'CoveredClass.php'    => array_merge(range(12, 27), range(37, 41)),
-                TEST_FILES_PATH . 'CoveredFunction.php' => range(10, 12),
-            ],
-            (new CodeCoverage)->linesToBeIgnored(TestSuite::fromClassName(IgnoringCodeUnitsTest::class)),
-        );
-    }
 }
